alloc_dmd: Allocates a constrained demand between receiving entities

View source: R/alloc_dmd.R

alloc_dmdR Documentation

Allocates a constrained demand between receiving entities

Description

Allocates a constrained demand between receiving entities

Usage

alloc_dmd(dataset, DFU, Period, Demand, Opening, Supply)

Arguments

dataset

a dataframe with the demand and supply features for an item per period

DFU

name of an item, a SKU, or a node like an item x location

Period

a period of time monthly or weekly buckets for example

Demand

the quantity of an item planned to be consumed in units for a given period

Opening

the opening inventories of an item in units at the beginning of the horizon

Supply

the quantity of an item planned to be supplied in units for a given period

Value

a dataframe with the calculated Projected Inventories and Coverages as well as the total Constrained Demand and the allocated demand between receiving entities

Examples

alloc_dmd(dataset = alloc_data, DFU, Period, Demand, Opening, Supply)


planr documentation built on March 28, 2026, 5:08 p.m.