const_dmd: Calculates the Projected Inventories and Coverages as well as...

View source: R/const_dmd.R

const_dmdR Documentation

Calculates the Projected Inventories and Coverages as well as the Constrained Demand and informs a Tag about the part of the Demand already covered by the Opening Inventories

Description

Calculates the Projected Inventories and Coverages as well as the Constrained Demand and informs a Tag about the part of the Demand already covered by the Opening Inventories

Usage

const_dmd(dataset, DFU, Period, Demand, Opening, Supply)

Arguments

dataset

a dataframe with the demand and supply features for an item per period

DFU

name of an item, a SKU, or a node like an item x location

Period

a period of time monthly or weekly buckets for example

Demand

the quantity of an item planned to be consumed in units for a given period

Opening

the opening inventories of an item in units at the beginning of the horizon

Supply

the quantity of an item planned to be supplied in units for a given period

Value

a dataframe with the calculated Projected Inventories and Coverages as well as the Constrained Demand and a Tag informing the part of the Demand already covered by the Opening Inventories

Examples

const_dmd(dataset = demo_const_dmd, DFU, Period, Demand, Opening, Supply)


planr documentation built on March 28, 2026, 5:08 p.m.