| cov_vol | R Documentation |
Calculates the calculated coverage expressed in volume of a coverage initially expressed in periods of time
cov_vol(dataset, DFU, Period, Demand, Coverage)
dataset |
a dataframe with the demand and supply features for an item per period |
DFU |
name of an item, a SKU, or a node like an item x location |
Period |
a period of time monthly or weekly buckets for example |
Demand |
the quantity of an item planned to be consumed in units for a given period |
Coverage |
the defined Coverage, expressed in number of periods |
a dataframe with the calculated coverage expressed in volume
cov_vol(dataset = cov_vol_data, DFU, Period, Demand, Coverage)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.