cov_vol_data: cov_vol_data

cov_vol_dataR Documentation

cov_vol_data

Description

This dataset contains the basic features to convert a coverage expressed in periods into a coverage expressed in units We can apply on it the cov_vol() function, it will return the related coverage in units

Usage

data(cov_vol_data)

Format

A data frame with 520 rows and 4 variables

Details

  • DFU, an item

  • Period, a date

  • Demand, a consumption in units

  • Coverage the targeted coverage that we want to convert, expressed in number of periods

Author(s)

Nicolas Nguyen nikonguyen@yahoo.fr


planr documentation built on March 28, 2026, 5:08 p.m.