demo_monthly_dmd: demo_monthly_dmd

demo_monthly_dmdR Documentation

demo_monthly_dmd

Description

This dataset contains a set of Monthly Demand for two Products. There are 3 variables: a DFU, a Monthly Period, a Monthly Demand. The idea is to use this dataset to convert the Demand from Monthly into Weekly bucket. We can apply on this dataset the month_to_week() function, it will create a weekly bucket Period and convert the Demand from Monthly into Weekly bucket.

Usage

data(demo_monthly_dmd)

Format

A data frame with 24 rows and 3 variables

Details

  • DFU, an item

  • Period, a date in monthly format

  • Demand, a consumption in units

Author(s)

Nicolas Nguyen nikonguyen@yahoo.fr


planr documentation built on March 28, 2026, 5:08 p.m.