month_to_week: Convert a Demand expressed in Monthly buckets into Weekly...

View source: R/month_to_week.R

month_to_weekR Documentation

Convert a Demand expressed in Monthly buckets into Weekly buckets

Description

Convert a Demand expressed in Monthly buckets into Weekly buckets

Usage

month_to_week(dataset, DFU, Period, Demand)

Arguments

dataset

a dataframe with the demand in monthly bucket for each item

DFU

name of an item, a SKU, or a node like an item x location

Period

a monthly period of time that we want to convert into weekly buckets

Demand

the quantity of an item planned to be consumed in units for a given period

Value

a dataframe with the Demand expressed in weekly buckets for each item

Examples

month_to_week(dataset = demo_monthly_dmd, DFU, Period, Demand)


planr documentation built on March 28, 2026, 5:08 p.m.