Learn R Programming

planr (version 0.6.3)

cov_vol: Calculates the calculated coverage expressed in volume of a coverage initially expressed in periods of time

Description

Calculates the calculated coverage expressed in volume of a coverage initially expressed in periods of time

Usage

cov_vol(dataset, DFU, Period, Demand, Coverage)

Value

a dataframe with the calculated coverage expressed in volume

Arguments

dataset

a dataframe with the demand and supply features for an item per period

DFU

name of an item, a SKU, or a node like an item x location

Period

a period of time monthly or weekly buckets for example

Demand

the quantity of an item planned to be consumed in units for a given period

Coverage

the defined Coverage, expressed in number of periods

Examples

Run this code
cov_vol(dataset = cov_vol_data, DFU, Period, Demand, Coverage)

Run the code above in your browser using DataLab