powered by
Calculates the calculated coverage expressed in volume of a coverage initially expressed in periods of time
cov_vol(dataset, DFU, Period, Demand, Coverage)
a dataframe with the calculated coverage expressed in volume
a dataframe with the demand and supply features for an item per period
name of an item, a SKU, or a node like an item x location
a period of time monthly or weekly buckets for example
the quantity of an item planned to be consumed in units for a given period
the defined Coverage, expressed in number of periods
cov_vol(dataset = cov_vol_data, DFU, Period, Demand, Coverage)
Run the code above in your browser using DataLab